@@ -34,44 +34,45 @@ read.ply <- function (file, ShowSpecimen = TRUE, addNormals = TRUE)
   format <- unlist(strsplit(grep(c("format "), plyfile, value = TRUE), " "))
   if (format[2] != "ascii")
     stop("PLY file is not ASCII format: ","format = ", format[2:length(format)])
-  poly <- NULL
+  face <- NULL
   material <- NULL
-  xline <- unlist(strsplit(grep(c("vertex "), plyfile, value = TRUE), " "))
-  npoints <- as.numeric(xline[grep(c("vertex"), xline) + 1])
+  xline <- unlist(strsplit(grep(c("element vertex "), plyfile, value = TRUE), " "))
+  nvertices <- as.numeric(xline[grep(c("vertex"), xline) + 1])
   yline <- unlist(strsplit(grep(c("element face"), plyfile, value = TRUE), " "))
-  npoly <- as.numeric(yline[grep(c("face"), yline) + 1])
+  nface <- as.numeric(yline[grep(c("face"), yline) + 1])
   headerend <- grep(c("end_header"), plyfile)
-  ncolpts <- (length(grep(c("property"), plyfile)) - 1)
-  cols <- grep(c("property"), plyfile, value = TRUE)
+  ncolpts <- (length(grep(c("property float"), plyfile)))
+  cols <- grep(c("property float"), plyfile, value = TRUE)
   x <- grep(c(" x"), cols)
   y <- grep(c(" y"), cols)
   z <- grep(c(" z"), cols)
+  nuchar <- (length(grep(c("property uchar"), plyfile)))
   points <- as.matrix(as.numeric(unlist(strsplit(plyfile[(headerend + 
-                                                            1):(headerend + npoints)], " "))))
-  dim(points) <- c(ncolpts, npoints)
-  xpts <- points[x ,]
-  ypts <- points[y ,]
-  zpts <- points[z ,]
+                                                            1):(headerend + nvertices)], " "))))
+  points <- matrix(points, nrow = nvertices, byrow = T)
+  xpts <- points[,x]
+  ypts <- points[,y]
+  zpts <- points[,z]
   vertices <- rbind(xpts, ypts, zpts, 1)
-  if (yline[3] == 0)
-    print("Object has zero faces")
+  if (yline[3] == 0) {print("Object has zero faces")}
   if (yline[3] != 0) {
-    poly <- as.matrix(as.numeric(unlist(strsplit(plyfile[(headerend + 
-                                                            npoints + 1):(headerend + npoints + npoly)], " "))))
-    dim(poly) <- c((poly[1] + 1), npoly)
-    poly <- poly[-1, ]
-    poly = poly +1 }
-  colinfo <- grep("property uchar red", plyfile)
-  if (length(colinfo) !=0) {
-    color <- rgb(points[4,], points[5,], points[6,], maxColorValue = 255)
-    material$color <- matrix(color[poly], dim(poly))}   
-  mesh <- list(vb = vertices, it = poly, primitivetype = "triangle", 
+    face <- as.matrix(as.numeric(unlist(strsplit(plyfile[(headerend + 
+                                                            nvertices + 1):(headerend + nvertices + nface)], " "))))
+    face <- t(matrix(face, nrow = nface, byrow = T))
+    face <- face[2:4,]
+    face = face +1 
+    }
+  if (nuchar !=0) {
+    color <- rgb(points[,4], points[,5], points[,6], maxColorValue = 255)
+    material$color <- matrix(color[face], dim(face))}   
+  
+  mesh <- list(vb = vertices, it = face, primitivetype = "triangle", 
                material = material)
   class(mesh) <- c("mesh3d", "shape3d")
   if(addNormals==TRUE){ mesh <- addNormals(mesh)}
   if(ShowSpecimen==TRUE){ 
     clear3d()
-    if (length(poly) == 0) { dot3d(mesh) }
+    if (length(face) == 0) { dot3d(mesh) }
     if (length(material) != 0){ shade3d(mesh) }
     shade3d(mesh, color="gray") }
   return(mesh)
